.. _user_guide:

User guide
==========

The ``pygranta`` metapackage itself is not used directly. Instead, it provides a bundle of
PyGranta packages that are compatible with each other and with a given Granta MI release.

The user guide for each PyGranta package provides usage information specific to that package.

PyGranta user guides
--------------------

.. grid:: 3

    .. grid-item-card:: PyGranta BoM Analytics :material-regular:`science` :material-regular:`eco`
      :padding: 2 2 2 2
      :link: https://bomanalytics.grantami.docs.pyansys.com/version/stable/user_guide/index.html
      :class-title: pyansys-card-title

    .. grid-item-card:: PyGranta RecordLists :material-regular:`list`
      :padding: 2 2 2 2
      :link: https://recordlists.grantami.docs.pyansys.com/version/stable/user_guide/index.html
      :class-title: pyansys-card-title

    .. grid-item-card:: PyGranta JobQueue :material-regular:`work_history`
      :padding: 2 2 2 2
      :link: https://jobqueue.grantami.docs.pyansys.com/version/stable/user_guide/index.html
      :class-title: pyansys-card-title

    .. grid-item-card:: PyGranta System :material-regular:`settings`
      :padding: 2 2 2 2
      :link: https://system.grantami.docs.pyansys.com/version/stable/user_guide/index.html
      :class-title: pyansys-card-title

    .. grid-item-card:: PyGranta Data Flow Extensions :material-outlined:`fork_right`
      :padding: 2 2 2 2
      :link: https://dataflow-extensions.grantami.docs.pyansys.com/version/stable/user_guide/index.html
      :class-title: pyansys-card-title
